@@ -32,9 +32,9 @@ QPythonWorker::~QPythonWorker()
 }
 
 void
-QPythonWorker::process(QVariant func, QVariant args, QJSValue *callback)
+QPythonWorker::process(QVariant func, QVariant unboxed_args, QJSValue *callback)
 {
-    QVariant result = qpython->call_sync(func, args);
+    QVariant result = qpython->call_internal(func, unboxed_args, false);
     if (callback) {
         emit finished(result, callback);
     }
@@ -48,3 +48,12 @@ QPythonWorker::import(QString name, QJSValue *callback)
         emit imported(result, callback);
     }
 }
+
+void
+QPythonWorker::import_names(QString name, QVariant args, QJSValue *callback)
+{
+    bool result = qpython->importNames_sync(name, args);
+    if (callback) {
+        emit imported(result, callback); // using the same imported signal at the end
+    }
+}
